##  Step 3. Report and Communicate
In the world of an ERP transformation journey, effective reporting and communication play a pivotal role in driving successful transformations. Share these and other views with your stakeholders to give them full transparency of the as-is architecture and aspects to consider. You should also use the reports to identify any gaps in your data and enrich data if needed.
In this step, do the following:
  1. Build an EA-centric Dashboard with KPIs and reports that are relevant for you to track, e.g., completion of items in the SAP LeanIX inventory and support the ERP transformation from EA perspective. There are some SAP LeanIX best practices you can leverage, which are shared below. This dashboard will evolve throughout the different phases of the transformation. To know more, see [Create a Custom Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.")
  2. Define a format in which you want to share your results with different stakeholders.
